"use strict";
/**
 * @author Timur Kuzhagaliyev <tim.kuzh@gmail.com>
 * @copyright 2020
 * @license MIT
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ToolbarSearch = void 0;
var InputAdornment_1 = __importDefault(require("@material-ui/core/InputAdornment"));
var TextField_1 = __importDefault(require("@material-ui/core/TextField"));
var react_1 = __importStar(require("react"));
var react_intl_1 = require("react-intl");
var react_redux_1 = require("react-redux");
var reducers_1 = require("../../redux/reducers");
var selectors_1 = require("../../redux/selectors");
var files_thunks_1 = require("../../redux/thunks/files.thunks");
var icons_types_1 = require("../../types/icons.types");
var hooks_helpers_1 = require("../../util/hooks-helpers");
var i18n_1 = require("../../util/i18n");
var icon_helper_1 = require("../../util/icon-helper");
var styles_1 = require("../../util/styles");
exports.ToolbarSearch = react_1.default.memo(function (_a) {
    var filterComponent = _a.filterComponent, filterInfoText = _a.filterInfoText;
    var intl = react_intl_1.useIntl();
    var searchPlaceholderString = intl.formatMessage({
        id: i18n_1.getI18nId(i18n_1.I18nNamespace.Toolbar, 'searchPlaceholder'),
        defaultMessage: 'Search',
    });
    var classes = useStyles();
    var ChonkyIcon = react_1.useContext(icon_helper_1.ChonkyIconContext);
    var searchInputRef = react_1.useRef();
    var dispatch = react_redux_1.useDispatch();
    var reduxSearchString = react_redux_1.useSelector(selectors_1.selectSearchString);
    var _b = react_1.useState(reduxSearchString), localSearchString = _b[0], setLocalSearchString = _b[1];
    var debouncedLocalSearchString = hooks_helpers_1.useDebounce(localSearchString, 300)[0];
    var _c = react_1.useState(false), showLoadingIndicator = _c[0], setShowLoadingIndicator = _c[1];
    react_1.useEffect(function () {
        dispatch(reducers_1.reduxActions.setFocusSearchInput(function () {
            if (searchInputRef.current)
                searchInputRef.current.focus();
        }));
        return function () {
            dispatch(reducers_1.reduxActions.setFocusSearchInput(null));
        };
    }, [dispatch]);
    react_1.useEffect(function () {
        setShowLoadingIndicator(false);
        dispatch(files_thunks_1.thunkUpdateSearchString(debouncedLocalSearchString));
    }, [debouncedLocalSearchString, dispatch]);
    var handleChange = react_1.useCallback(function (event) {
        setShowLoadingIndicator(true);
        setLocalSearchString(event.currentTarget.value);
    }, []);
    var handleKeyUp = react_1.useCallback(function (event) {
        // Remove focus from the search input field when user presses escape.
        // Note: We use KeyUp instead of KeyPress because some browser plugins can
        //       intercept KeyPress events with Escape key.
        //       @see https://stackoverflow.com/a/37461974
        if (event.key === 'Escape') {
            setLocalSearchString('');
            dispatch(files_thunks_1.thunkUpdateSearchString(''));
            if (searchInputRef.current)
                searchInputRef.current.blur();
        }
    }, [dispatch]);
    return (react_1.default.createElement(TextField_1.default, { className: classes.searchFieldContainer, margin: "dense", size: "small", variant: "outlined", value: localSearchString, placeholder: searchPlaceholderString, onChange: handleChange, inputRef: searchInputRef, helperText: filterInfoText !== null && filterInfoText !== void 0 ? filterInfoText : '', InputProps: {
            onKeyUp: handleKeyUp,
            startAdornment: filterComponent ? (react_1.default.createElement(InputAdornment_1.default, { position: "start" }, filterComponent)) : null,
            endAdornment: (react_1.default.createElement(InputAdornment_1.default, { className: classes.searchIcon, position: "end" },
                react_1.default.createElement(ChonkyIcon, { icon: showLoadingIndicator
                        ? icons_types_1.ChonkyIconName.loading
                        : icons_types_1.ChonkyIconName.search, spin: showLoadingIndicator }))),
        } }));
});
var useStyles = styles_1.makeGlobalChonkyStyles(function (theme) {
    var _a, _b, _c;
    return ({
        searchFieldContainer: {
            width: 250,
        },
        searchIcon: {
            fontSize: '0.9em',
            opacity: 0.75,
            color: (_c = (_b = (_a = theme === null || theme === void 0 ? void 0 : theme.palette) === null || _a === void 0 ? void 0 : _a.primary) === null || _b === void 0 ? void 0 : _b.main) !== null && _c !== void 0 ? _c : 'black',
        },
    });
});
